@@ -11,7 +11,7 @@ from rich.text import Text
 from .cached_object import CachedObject
 from .filter import Filter
 from .stack import Stack, StackFrame
-from .utils import is_selectable
+from .config import box_type
 
 console = Console()
 
@@ -28,14 +28,13 @@ class ExplorerState:
 
 
 def get_state(cached_obj: CachedObject):
-    _type = type(cached_obj.obj)
-    if _type == dict:
+    if isinstance(cached_obj.obj, dict):
         return ExplorerState.dict
-    elif _type == list:
+    elif isinstance(cached_obj.obj, list):
         return ExplorerState.list
-    elif _type == tuple:
+    elif isinstance(cached_obj.obj, tuple):
         return ExplorerState.tuple
-    elif _type == set:
+    elif isinstance(cached_obj.obj, set):
         return ExplorerState.set
     else:
         return ExplorerState.public
@@ -248,6 +247,7 @@ class Explorer:
             subtitle=subtitle,
             subtitle_align="right",
             style="white",
+            box=box_type
         )
 
     @property
@@ -315,10 +315,12 @@ class Explorer:
             subtitle=f"([magenta]{self.dict_index + 1}[/magenta]/[magenta]{len(self.cached_obj.filtered_dict)}[/magenta])",
             subtitle_align="right",
             style="white",
+            box=box_type
         )
 
     @property
     def list_panel(self) -> Panel:
+        """ TODO """
         # Reset the list index / window in case applying a filter has now moved the index
         # farther down than it can access on the filtered attributes
         if self.list_index >= len(self.cached_obj.filtered_list):
@@ -386,12 +388,11 @@ class Explorer:
             subtitle=f"([magenta]{self.list_index + 1}[/magenta]/[magenta]{len(self.cached_obj.filtered_list)}[/magenta])",
             subtitle_align="right",
             style="white",
+            box=box_type
         )
 
     def explore_selected_object(self) -> Optional[CachedObject]:
         """ TODO """
-        if not is_selectable(self.selected_object.obj):
-            return self.cached_obj
 
         # Save current stack as a frame
         current_frame = StackFrame(
@@ -666,7 +667,7 @@ class Explorer:
         return self.num_attributes < 130
 
     @property
-    def selected_object(self) -> CachedObject:  # type: ignore
+    def selected_object(self) -> CachedObject:
         """ Return the currently selected cached object """
         try:
             if self.state == ExplorerState.public:
@@ -682,8 +683,9 @@ class Explorer:
                 return self.cached_obj.filtered_private_attributes[attr]
 
             elif self.state == ExplorerState.dict:
-                attr = list(self.cached_obj.filtered_dict)[self.dict_index]
-                return self.cached_obj.filtered_dict[attr][1]
+                # Get the currently selected key
+                key = list(self.cached_obj.filtered_dict)[self.dict_index]
+                return self.cached_obj.filtered_dict[key].cached_object
 
             elif self.state in (
                 ExplorerState.list,
@@ -691,6 +693,8 @@ class Explorer:
                 ExplorerState.set,
             ):
                 return self.cached_obj.filtered_list[self.list_index][1]
+            else:
+                raise ValueError("Unexpected explorer state")
 
         except (KeyError, IndexError):
             return CachedObject(None)
