@@ -6,9 +6,9 @@ import subprocess
 import time
 from typing import Any, Optional, Union
 
-import blessed
 import rich
 from blessed import Terminal
+from blessed.keyboard import Keystroke
 from rich.console import Console
 from rich.layout import Layout
 from rich.panel import Panel
@@ -20,6 +20,7 @@ from .cached_object import CachedObject
 from .explorer import Explorer, ExplorerState
 from .help_layout import HelpState, random_error_quote
 from .overview import Overview, OverviewState, PreviewState
+from .config import box_type
 
 # TODO object highlighted on stack view should be shown on the overview
 # TODO support ctrl-a + (whatever emacs keybinding to go to end of line)
@@ -27,7 +28,7 @@ from .overview import Overview, OverviewState, PreviewState
 # TODO builtin frame/stack explorer? from objexplore import stackexplore
 
 
-version = "1.5.7"
+version = "1.6.0"
 console = Console()
 EDITOR = os.environ.get("EDITOR")
 
@@ -35,15 +36,17 @@ EDITOR = os.environ.get("EDITOR")
 class ObjExploreApp:
     """ Main Application class """
 
-    def __init__(self, obj: Any, name_of_obj: str):
-        cached_obj = CachedObject(obj, attr_name=name_of_obj)
+    error_style = Style(color="red")
+    main_style  = Style(color="blue")
+    term = Terminal()
+
+    def __init__(self, obj: Any, name: str):
+        cached_obj = CachedObject(obj, attr_name=name)
         # Figure out all the attributes of the current obj's attributes
         cached_obj.cache()
 
-        self.term = Terminal()
         self.explorer = Explorer(term=self.term, cached_obj=cached_obj)
         self.overview = Overview(term=self.term, version=version)
-        self.main_style = Style(color="blue")
 
         # Run self.draw() whenever the win change signal is caught
         try:
@@ -53,7 +56,7 @@ class ObjExploreApp:
             pass
 
     def explore(self) -> Optional[Any]:
-        """ Open the interactive explorer """
+        """ Open the interactive explorer. This is the main running loop """
 
         key = None
         res = None
@@ -69,7 +72,7 @@ class ObjExploreApp:
                     self.process_key_event(key)
 
                 except RuntimeError as err:
-                    # Some kind of error during resizing events. Ignore and continue
+                    # Some kind of error thrown during resizing events. Ignore and continue
                     if (
                         err.args[0]
                         == "reentrant call inside <_io.BufferedWriter name='<stdout>'>"
@@ -88,7 +91,7 @@ class ObjExploreApp:
 
         return res
 
-    def process_key_event(self, key: blessed.keyboard.Keystroke) -> Any:
+    def process_key_event(self, key: Keystroke) -> Any:
         """ Process the incoming key """
 
         if self.explorer.filter.receiving_input:
@@ -151,7 +154,7 @@ class ObjExploreApp:
             ):
                 # Continue on and process these keys as normal
                 self.overview.help_layout.visible = False
-
+                # Do not return so we can run the key action after the help window has closed
             else:
                 return
 
@@ -236,7 +239,7 @@ class ObjExploreApp:
             self.explorer.filter.move_down()
 
         elif (
-            key == "k" or key.code == self.term.KEY_CODE
+            key == "k" or key.code == self.term.KEY_UP
         ) and self.explorer.filter.layout.visible:
             self.explorer.filter.move_up()
 
@@ -341,7 +344,6 @@ class ObjExploreApp:
 
             with console.capture() as capture:
                 console.print(printable)
-
             str_out = capture.get()
             pydoc.pager(str_out)
 
@@ -375,8 +377,8 @@ class ObjExploreApp:
             str_out = capture.get()
             pydoc.pager(str_out)
 
-    def draw(self, *args):
-        """ Draw the application. the *args argument is due to resize events and are unused """
+    def draw(self, *_):
+        """ Draw the application. the *_ argument is due to resize events and are unused """
         print(self.term.home, end="")
         layout = Layout()
         layout.split_row(
@@ -401,28 +403,47 @@ class ObjExploreApp:
             subtitle_align="left",
             height=self.term.height - 1,
             style=self.main_style,
+            box=box_type
         )
         rich.print(object_explorer, end="")
 
     def error(self):
-        self.main_style = Style(color="red")
+        """ Color the outside red and pause for a split second """
+        self.main_style = self.error_style
         self.draw()
         time.sleep(0.25)
-        self.main_style = Style(color="blue")
+        self.main_style = self.main_style
 
 
 def explore(obj: Any) -> Any:
-    """ Run the explorer on the given object """
-    # Get the name of the variable sent to this function
-    # If someone calls this function like:
-    # >>> df = pandas.DataFrame()
-    # >>> explore(df)
-    # Then we want to extract `name` == 'df'
+    """
+    Run the explorer on the given object
+
+    Get the name of the variable sent to this function
+    If someone calls this function like:
+    >>> df = pandas.DataFrame()
+    >>> explore(df)
+    Then we want to extract the string 'df' to the variable `name`
+    Depending on if explore is called from a script or from the REPL,
+    `name` may or may not refer to the correct object
+    If called from the REPL:
+    >>> x = 'hello'
+    >>> y = 'world'
+    >>> explore(x)
+    then name == 'x'
+    If called from a script:
+    python -c "x = 'hello'; y = 'world'; import objexplore; objexplore.explore(x)"
+    then name == 'y'
+
+    I dont know of any way to fix this
+    """
+
     frame = inspect.currentframe()
     name = frame.f_back.f_code.co_names[1]  # type: ignore
-    app = ObjExploreApp(obj, name_of_obj=name)
+    app = ObjExploreApp(obj, name=name)
     try:
         return app.explore()
+
     except Exception as err:
         print(app.term.move_down(app.term.height))
         console.print_exception(show_locals=True)
